@@ -9,7 +9,7 @@ import sys
 
 import openstack
 
-from cloudmesh.abstract.ComputeNodeABC import ComputeNodeABC
+from cloudmesh.abstractclass.ComputeNodeABC import ComputeNodeABC
 from cloudmesh.common.DateTime import DateTime
 from cloudmesh.common.DictList import DictList
 from cloudmesh.common.Printer import Printer
@@ -98,7 +98,6 @@ class Provider(ComputeNodeABC, ComputeProviderPlugin):
             "sort_keys": ["cm.name"],
             "order": ["cm.name",
                       "cm.cloud",
-                      "cm.label",
                       "vm_state",
                       "status",
                       "task_state",
@@ -106,11 +105,10 @@ class Provider(ComputeNodeABC, ComputeProviderPlugin):
                       "metadata.flavor",
                       "ip_public",
                       "ip_private",
-                      "cm.creation",
+                      "cm.creation_time",
                       "launched_at"],
             "header": ["Name",
                        "Cloud",
-                       "Label",
                        "State",
                        "Status",
                        "Task",
@@ -922,7 +920,6 @@ class Provider(ComputeNodeABC, ComputeProviderPlugin):
                group=None,
                metadata=None,
                cloud=None,
-               label=None,
                **kwargs):
         """
         creates a named node
@@ -986,13 +983,9 @@ class Provider(ComputeNodeABC, ComputeProviderPlugin):
         if type(group) == str:
             groups = Parameter.expand(group)
 
-        vm_label = label or name
-
-
         banner("Create Server")
         Console.msg(f"    Cloud:    {self.cloud}")
         Console.msg(f"    Name:     {name}")
-        Console.msg(f"    Label:    {vm_label}")
         Console.msg(f"    User:     {user}")
         Console.msg(f"    IP:       {ip}")
         Console.msg(f"    Image:    {image}")
@@ -1044,16 +1037,8 @@ class Provider(ComputeNodeABC, ComputeProviderPlugin):
             if metadata is None:
                 metadata = {}
 
-            #
-            # due to metadata limitation in openstack do not add the creation time
-            #
-
-            if 'created' in metadata:
-                del metadata['created']
-
             metadata['image'] = image
             metadata['flavor'] = size
-            metadata['label'] = vm_label
 
             self.cloudman.set_server_metadata(server, metadata)
 
